Index: sansguiframe/src/sans/guiframe/local_perspectives/plotting/AnnulusSlicer.py
===================================================================
--- sansguiframe/src/sans/guiframe/local_perspectives/plotting/AnnulusSlicer.py	(revision 8c347a61193367bd8a75b5a9949e34a45f6b9385)
+++ sansguiframe/src/sans/guiframe/local_perspectives/plotting/AnnulusSlicer.py	(revision db7a82e416cb65e5ed7c39ea7ec02a29538eec55)
@@ -125,5 +125,5 @@
             return
         
-        from DataLoader.manipulations import Ring
+        from sans.dataloader.manipulations import Ring
         rmin = min(math.fabs(self.inner_circle.get_radius()),
                   math.fabs(self.outer_circle.get_radius()))
@@ -535,5 +535,5 @@
             return
         mask = data.mask  
-        from DataLoader.manipulations import Ringcut
+        from sans.dataloader.manipulations import Ringcut
     
         rmin = 0
Index: sansguiframe/src/sans/guiframe/local_perspectives/plotting/SectorSlicer.py
===================================================================
--- sansguiframe/src/sans/guiframe/local_perspectives/plotting/SectorSlicer.py	(revision 8c347a61193367bd8a75b5a9949e34a45f6b9385)
+++ sansguiframe/src/sans/guiframe/local_perspectives/plotting/SectorSlicer.py	(revision db7a82e416cb65e5ed7c39ea7ec02a29538eec55)
@@ -146,5 +146,5 @@
             return
         ## Averaging
-        from DataLoader.manipulations import SectorQ
+        from sans.dataloader.manipulations import SectorQ
         radius = self.qmax 
         phimin =  -self.left_line.phi + self.main_line.theta
Index: sansguiframe/src/sans/guiframe/local_perspectives/plotting/boxMask.py
===================================================================
--- sansguiframe/src/sans/guiframe/local_perspectives/plotting/boxMask.py	(revision 8c347a61193367bd8a75b5a9949e34a45f6b9385)
+++ sansguiframe/src/sans/guiframe/local_perspectives/plotting/boxMask.py	(revision db7a82e416cb65e5ed7c39ea7ec02a29538eec55)
@@ -148,5 +148,5 @@
         contained in that region and the error on that sum
         """
-        from DataLoader.manipulations import Boxcut
+        from sans.dataloader.manipulations import Boxcut
         ## Data 2D for which the pixel will be summed
         data = self.base.data
Index: sansguiframe/src/sans/guiframe/local_perspectives/plotting/boxSlicer.py
===================================================================
--- sansguiframe/src/sans/guiframe/local_perspectives/plotting/boxSlicer.py	(revision 8c347a61193367bd8a75b5a9949e34a45f6b9385)
+++ sansguiframe/src/sans/guiframe/local_perspectives/plotting/boxSlicer.py	(revision db7a82e416cb65e5ed7c39ea7ec02a29538eec55)
@@ -538,5 +538,5 @@
         Post data creating by averaging in Qx direction
         """
-        from DataLoader.manipulations import SlabX
+        from sans.dataloader.manipulations import SlabX
         self.post_data(SlabX, direction="X")   
         
@@ -555,5 +555,5 @@
         Post data creating by averaging in Qy direction
         """
-        from DataLoader.manipulations import SlabY
+        from sans.dataloader.manipulations import SlabY
         self.post_data(SlabY, direction="Y")   
         
Index: sansguiframe/src/sans/guiframe/local_perspectives/plotting/boxSum.py
===================================================================
--- sansguiframe/src/sans/guiframe/local_perspectives/plotting/boxSum.py	(revision 8c347a61193367bd8a75b5a9949e34a45f6b9385)
+++ sansguiframe/src/sans/guiframe/local_perspectives/plotting/boxSum.py	(revision db7a82e416cb65e5ed7c39ea7ec02a29538eec55)
@@ -179,5 +179,5 @@
         y_max = self.vertical_lines.y1
         ##computation of the sum and its error
-        from DataLoader.manipulations import Boxavg
+        from sans.dataloader.manipulations import Boxavg
         box =  Boxavg(x_min=x_min, x_max=x_max, y_min=y_min, y_max=y_max)
         self.count, self.error = box(self.base.data2D)
Index: sansguiframe/src/sans/guiframe/local_perspectives/plotting/sectorMask.py
===================================================================
--- sansguiframe/src/sans/guiframe/local_perspectives/plotting/sectorMask.py	(revision 8c347a61193367bd8a75b5a9949e34a45f6b9385)
+++ sansguiframe/src/sans/guiframe/local_perspectives/plotting/sectorMask.py	(revision db7a82e416cb65e5ed7c39ea7ec02a29538eec55)
@@ -121,5 +121,5 @@
         mask = data.mask
         ## Averaging
-        from DataLoader.manipulations import Sectorcut
+        from sans.dataloader.manipulations import Sectorcut
         radius = self.qmax 
         phimin =  -self.left_line.phi + self.main_line.theta

Index: sansguiframe/src/sans/guiframe/local_perspectives/plotting/AzimutSlicer.py
===================================================================
--- sansguiframe/src/sans/guiframe/local_perspectives/plotting/AzimutSlicer.py	(revision 8c347a61193367bd8a75b5a9949e34a45f6b9385)
+++ sansguiframe/src/sans/guiframe/local_perspectives/plotting/AzimutSlicer.py	(revision db7a82e416cb65e5ed7c39ea7ec02a29538eec55)
@@ -173,5 +173,5 @@
         #print "phimin, phimax, rmin ,rmax",math.degrees(phimin),
         # math.degrees(phimax), rmin ,rmax
         #from DataLoader.manipulations import SectorQ
         
         sect = new_sector(r_min=rmin, r_max=rmax,
@@ -290,5 +290,5 @@
         """
         """
-        from DataLoader.manipulations import SectorQ
+        from sans.dataloader.manipulations import SectorQ
         self.post_data(SectorQ)   
         
@@ -307,5 +307,5 @@
         """
         """
-        from DataLoader.manipulations import SectorPhi
+        from sans.dataloader.manipulations import SectorPhi
         self.post_data(SectorPhi )   
         
@@ -173,5 +173,5 @@
         #print "phimin, phimax, rmin ,rmax",math.degrees(phimin),
         # math.degrees(phimax), rmin ,rmax
-        #from DataLoader.manipulations import SectorQ
+        #from sans.dataloader.manipulations import SectorQ
         
         sect = new_sector(r_min=rmin, r_max=rmax,